<?php
namespace App;

use DI\ContainerBuilder;
use Interop\Container\ContainerInterface;

class App extends \DI\Bridge\Slim\App {

    protected function configureContainer(ContainerBuilder $builder)
    {
        $definitions = [
            'settings.displayErrorDetails' => true,

            \Doctrine\DBAL\Connection::class => function () {
                
                if(!file_exists(__DIR__ . '/../environment/environment.json')) {
                    throw new \Exception("environment not found!");
                }

                $environmentFile = file_get_contents(__DIR__ . '/../environment/environment.json');
                $environment     = json_decode($environmentFile, true);

                $connection = null;

                if($environment['driver'] == 'oci8') {
                    $connection = \Doctrine\DBAL\DriverManager::getConnection(array(
                        'user'     => $environment['user'],
                        'password' => $environment['password'],
                        'host'     => $environment['host'],
                        'port'     => $environment['port'],
                        'dbname'   => $environment['dbname'],
                        'service'  => $environment['service'],
                        'driver'   => $environment['driver'],
                        'charset'  => $environment['charset']
                    ), $config = new \Doctrine\DBAL\Configuration);
                } else if ($environment['driver'] == 'sqlsrv') {
                    $connection = \Doctrine\DBAL\DriverManager::getConnection(array(
                        'user'     => $environment['user'],
                        'password' => $environment['password'],
                        'host'     => $environment['host'],
                        'port'     => $environment['port'],
                        'dbname'   => $environment['dbname'],
                        'driver'   => $environment['driver']
                    ), $config = new \Doctrine\DBAL\Configuration);
                }
                return $connection;
            }
        ];

        $builder->addDefinitions($definitions);
    }
}